@@ -27,7 +27,8 @@ class DynamicTestCases(object):
             ...  log hello, world  WARN
         """
         tc = self.current_suite.tests.create(name=name, doc=doc, tags=tags)
-        tc.keywords.create(name=kwname, args=args)
+        tc.body.create_keyword(name=kwname, args=args)
+        # tc.keywords.create(name=kwname, args=args)
 
 # To get our class to load, the module to have a class
 # with the same name of a module. This makes that happen:
