@@ -181,7 +181,7 @@ class RequestsProKeywords(RequestsLibrary):
                                                         debug=debug, max_retries=max_retries,
                                                         backoff_factor=backoff_factor,
                                                         disable_warnings=1)
-            # Trigger Get method
+            # Trigger GET method
             response = super(RequestsLibrary, self).get_request(alias=alias, uri=uri, headers=headers, json=data,
                                                                 params=params, allow_redirects=None, timeout=timeout)
         elif request_type == 'PUT':
@@ -193,7 +193,7 @@ class RequestsProKeywords(RequestsLibrary):
                                                         debug=debug, max_retries=max_retries,
                                                         backoff_factor=backoff_factor,
                                                         disable_warnings=1)
-            # Trigger Get method
+            # Trigger PUT method
             response = super(RequestsLibrary, self).put_request(alias=alias, uri=uri, data=data, json=json_data,
                                                                 params=params, files=files, headers=headers,
                                                                 allow_redirects=None, timeout=timeout)
@@ -204,10 +204,21 @@ class RequestsProKeywords(RequestsLibrary):
                                                         debug=debug, max_retries=max_retries,
                                                         backoff_factor=backoff_factor,
                                                         disable_warnings=1)
-            # Trigger Get method
+            # Trigger POST method
             response = super(RequestsLibrary, self).post_request(alias=alias, uri=uri, data=data, json=json_data,
                                                                  params=params, headers=headers, files=files,
                                                                  allow_redirects=None, timeout=timeout)
+        elif request_type == 'DELETE':
+            # Create Session
+            super(RequestsLibrary, self).create_session(alias=alias, url=base_url, headers=headers, cookies=cookies,
+                                                        auth=auth, timeout=timeout, proxies=proxies, verify=verify,
+                                                        debug=debug, max_retries=max_retries,
+                                                        backoff_factor=backoff_factor,
+                                                        disable_warnings=1)
+            # Trigger DELETE method
+            response = super(RequestsLibrary, self).delete_request(alias=alias, uri=uri, data=data, json=json_data,
+                                                                   params=params, headers=headers, allow_redirects=None,
+                                                                   timeout=timeout)
 
         selected_api_df.loc[0, 'API_Response_Code'] = response.status_code
         if response.text != '':
